polyfemos.back.interpreter — polyfemos 0.3.29 documentation

# polyfemos.back.interpreter

Contains `Interpreter` for reading ‘*conf’ files

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.back.interpreter.` `check_quit`(func_)

  A decorator to be used with methods of class `Interpreter`. If the class attribute `self._quit` is set to `False`, the decorated methods do nothing.

  Parameters

    func_ (func) –

  Return type

    func

  Returns

`polyfemos.back.interpreter.` `pool_error_callback`(arg, msg='')

  A function to be called during pool worker error

  Parameters

    - arg – Error message

    - msg (str, optional) – Additional message

Classes

`Interpreter`() | Class for reading ‘*.conf’ files